¿Qué es OiRA? | OiRA

Temas

# ¿Qué es OiRA?

## ¿Nuevo en OiRA?

Aquí encontrará una breve introducción sobre qué es una evaluación de riesgos y cómo puede ayudarle OiRA a gestionarla.

¿En qué consiste la evaluación de riesgos?

La evaluación de riesgos es la base para una gestión eficaz de la seguridad y la salud, así como la clave para reducir los accidentes de trabajo y las enfermedades profesionales. Si se aplica adecuadamente, puede mejorar la seguridad y la salud en los lugares de trabajo y el rendimiento de las empresas en general.

La seguridad y la salud de los trabajadores estarán protegidas en Europa mediante la evaluación y la gestión de los riesgos en el trabajo. Las empresas tienen la obligación legal de garantizar la seguridad y la salud de los trabajadores en todos los aspectos relacionados con el trabajo y de efectuar evaluaciones de riesgos. Por lo tanto, toda empresa debe llevar a cabo una evaluación de riesgos y elaborar un plan de acción. Para poder realizar una evaluación eficaz de los riesgos en el lugar de trabajo, todos los implicados deben comprender claramente:

- el contexto y los conceptos jurídicos
- el proceso utilizado para evaluar los riesgos
- el papel que desempeñarán los principales agentes que intervienen en el proceso

Los trabajadores o sus representantes tienen derecho a ser consultados sobre los mecanismos para realizar la evaluación de riesgos y participar en ella.

Puede encontrar más información sobre la evaluación de riesgos y sobre la participación de los trabajadores o sus representantes en el proceso de evaluación de riesgos en la página web del proyecto OiRA.

You can find more information on risk assessment and about the participation of workers and/or their representatives in the risk assessment process on the website of the OiRA project.

## ¿Qué es OiRA?

OiRA significa Online Interactive Risk Assessment (evaluación interactiva de riesgos en línea). Se trata de una aplicación basada en la Web que le permite realizar una evaluación de riesgos para la salud y la seguridad en su lugar de trabajo.

## ¿A quién va destinada OiRA?

Cualquier persona puede utilizar OiRA para evaluar los riesgos relacionados con la salud y la seguridad que puedan existir en su lugar de trabajo.

Sin embargo, OiRA ha sido concebida para aportar el máximo valor a las empresas más pequeñas. OiRA se ha desarrollado específicamente para ayudarlas a evaluar los riesgos en el trabajo y a elaborar una evaluación de riesgos documentada que incluya un plan de acción adaptado a los requisitos del centro de trabajo.

## ¿Qué tengo que hacer?

Debe usted completar varios pasos en el proceso de evaluación de riesgos con OiRA:

- Preparación: Algunas herramientas incluyen preguntas de perfil que le ayudan a adaptar la herramienta en función de las especificidades de su centro de trabajo. Cuando conteste a las preguntas de perfil, la herramienta se adaptará a su situación específica y le mostrará los módulos aplicables a su situación específica.

- Participación: Toda evaluación de riesgos debe realizarse con la participación activa de los trabajadores. La herramienta le ofrece la posibilidad de imprimir el texto completo de la evaluación de riesgos o partes de la misma para informar a los trabajadores y recabar sus comentarios.

- Identificación de riesgos: OiRA presentará una serie de posibles riesgos o problemas de salud y seguridad que podrían plantearse en su lugar de trabajo. Al contestar a las declaraciones/preguntas con un sí o un no, indica usted si existen tales peligros o problemas. También puede decidir dejar una pregunta sin responder y dejarla pendiente para contestarla más adelante.

- Evaluación: Algunas herramientas le piden que jerarquice los riesgos identificados. Existen diferentes formas de hacerlo, en función de las decisiones adoptadas por nuestros socios/desarrolladores nacionales de la herramienta OiRA y su enfoque específico. Algunas herramientas también establecen automáticamente la jerarquización de los riesgos en segundo plano, y usted puede anular estas prioridades.

- Plan de acción: Para cada riesgo identificado, la herramienta le pide que opte por una o varias medidas para eliminar o reducir el riesgo. La mayoría de las herramientas le proponen ya algunas medidas. También puede optar por introducir sus propias medidas.

- Informe: Tiene usted la obligación legal de documentar su evaluación de riesgos. En la sección de informes, encontrará una serie de informes que le ayudarán a llevar un registro de su evaluación de riesgos y hacer un seguimiento de las acciones/medidas que ha decidido aplicar para eliminar o mitigar los riesgos identificados.

## ¿Cuánto tiempo llevará?

Es imposible decir cuánto tiempo durará una evaluación con carácter general, ya que las herramientas difieren en función de los sectores y los países.

Sin embargo, puede dedicar el tiempo que tenga disponible a una evaluación y luego volver a ella cuando lo crea conveniente para retomarla desde el punto en el que la dejó.

## ¿Por qué tengo que registrarme?

La primera acción que se pedirá de usted cuando inicie su primera evaluación de riesgos es crear una cuenta OiRA, un proceso sencillo y rápido.

Registrarse le permite iniciar sesión en cualquier momento para continuar con las evaluaciones anteriores o iniciar otras nuevas. Si es usted un usuario registrado, también tendrá la opción de obtener una evaluación de riesgos impresa, exacta y actualizada en cualquier momento.

## ¿Tengo que preparar algo?

No necesita ningún tipo de preparación específica para empezar a utilizar la herramienta, pero debe dedicar tiempo a pensar en quién va a llevar a cabo la evaluación de riesgos, cómo van a participar los trabajadores en el proceso, etc.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More